@@ -1,20 +1,23 @@
+import argparse
+import os
 import subprocess
 import sys
-import os
-import argparse
+import traceback
+
 from zuper_commons.logs import setup_logging
+
 from . import logger
 from .commons import get_dir_info
-import traceback
-__all__ = ['aido_check_tagged_main']
+
+__all__ = ["aido_check_tagged_main"]
+
 
 def aido_check_tagged_main(args=None):
     setup_logging()
 
-
     parser = argparse.ArgumentParser()
-    parser.add_argument('--directory', '-d',  default=".")
-    parser.add_argument('cmd', nargs='*')
+    parser.add_argument("--directory", "-d", default=".")
+    parser.add_argument("cmd", nargs="*")
     parsed = parser.parse_args(args)
 
     try:
@@ -28,8 +31,7 @@ def aido_check_tagged_main(args=None):
         di = get_dir_info(directory)
 
         if di.tag is None:
-            logger.error('This is not tagged. ',
-                         directory=absdir, di=di, rest=" ".join(rest))
+            logger.error("This is not tagged. ", directory=absdir, di=di, rest=" ".join(rest))
             sys.exit(1)
 
         else:
